==> slim-3.1.1.tar.gz: lib/src/extensions.dart <==
import 'package:flutter/material.dart';
import 'localization.dart';
import 'state_management.dart';

extension SlimStringX on String {
  /// true if string is null or empty
  bool get isNullOrEmpty => (this ?? '').isEmpty;

  /// true if string is not null or empty
  bool get isNotNullOrEmpty => (this ?? '').isNotEmpty;
}

extension SlimWidgetX on Widget {
  /// push widget to navigation stack
  Future<T> push<T>(BuildContext context) =>
      context.push(MaterialPageRoute(builder: (_) => this));

  /// replace current navigation to widget
  Future<T> pushReplacement<T>(BuildContext context) =>
      context.pushReplacement(MaterialPageRoute(builder: (_) => this));

  /// make widget the only widget in navigation stack
  Future<T> pushTop<T>(BuildContext context) {
    context.popTop();
    return context.pushReplacement<T>(MaterialPageRoute(builder: (_) => this));
  }
}

extension SlimBuildContextContextX on BuildContext {
  /// access the nearest top T in tree
  T slim<T>() => Slim.of<T>(this);

  /// media query width
  double get width => MediaQuery.of(this).size.width;

  /// media query height
  double get height => MediaQuery.of(this).size.height;

  /// current navigator state
  NavigatorState get navigator => Navigator.of(this);

  /// pop navigation stack
  void pop<T>({T result}) => navigator.pop<T>(result);

  /// push to navigation stack
  Future<T> push<T>(Route<T> route) => navigator.push<T>(route);

  /// replace top navigation stack
  Future<T> pushReplacement<T>(Route<T> route) =>
      navigator.pushReplacement(route);

  /// pop navigation stack to a single navigation
  void popTop() {
    while (navigator.canPop()) navigator.pop();
  }

  /// get locale translation by key
  String translate(String key) =>
      SlimLocalizations.slimLocaleLoader.translate(key);

  /// get os locale text direction
  TextDirection get textDirection =>
      Localizations.of<WidgetsLocalizations>(this, WidgetsLocalizations)
          .textDirection;
}

==> slim-3.1.7.tar.gz: lib/src/extensions.dart <==
import 'package:flutter/material.dart';
import 'localization.dart';
import 'state_management.dart';

/// Useful extension methods on [String]
extension SlimStringX on String {
  /// True if null or empty
  bool get isNullOrEmpty => (this ?? '').isEmpty;

  /// True if not null or empty
  bool get isNotNullOrEmpty => (this ?? '').isNotEmpty;
}

/// Useful extension methods on [Widget]
extension SlimWidgetX on Widget {
  /// Push widget to navigation stack
  Future<T> push<T>(BuildContext context) =>
      context.push(MaterialPageRoute(builder: (_) => this));

  /// Replace current navigation to widget
  Future<T> pushReplacement<T>(BuildContext context) =>
      context.pushReplacement(MaterialPageRoute(builder: (_) => this));

  /// Make widget the only widget in navigation stack
  Future<T> pushTop<T>(BuildContext context) {
    context.popTop();
    return context.pushReplacement<T>(MaterialPageRoute(builder: (_) => this));
  }
}

/// Useful extension methods on [BuildContext]
extension SlimBuildContextContextX on BuildContext {
  /// Access the nearest T up the tree
  T slim<T>() => Slim.of<T>(this);

  /// [MediaQuery] width
  double get width => MediaQuery.of(this).size.width;

  /// [MediaQuery] height
  double get height => MediaQuery.of(this).size.height;

  /// Current navigator state
  NavigatorState get navigator => Navigator.of(this);

  /// Pop navigation stack
  void pop<T>({T result}) => navigator.pop<T>(result);

  /// Push to navigation stack
  Future<T> push<T>(Route<T> route) => navigator.push<T>(route);

  /// Replace top navigation stack
  Future<T> pushReplacement<T>(Route<T> route) =>
      navigator.pushReplacement(route);

  /// Pop navigation stack to a single navigation
  void popTop() {
    while (navigator.canPop()) navigator.pop();
  }

  /// Get current locale translation by key
  String translate(String key) =>
      SlimLocalizations.slimLocaleLoader.translate(key);

  /// Get OS locale text direction
  TextDirection get textDirection =>
      Localizations.of<WidgetsLocalizations>(this, WidgetsLocalizations)
          .textDirection;
}
